searchNodes=[{"ref":"Statistex.html","title":"Statistex","type":"module","doc":"Calculate all the statistics for given samples. Works all at once with statistics/1 or has a lot of functions that can be triggered individually. To avoid wasting computation, function can be given values they depend on as optional keyword arguments so that these values can be used instead of recalculating them. For an example see average/2. Most statistics don&#39;t really make sense when there are no samples, for that reason all functions except for sample_size/1 raise ArgumentError when handed an empty list. It is suggested that if it&#39;s possible for your program to throw an empty list at Statistex to handle that before handing it to Staistex to take care of the &quot;no reasonable statistics&quot; path entirely separately. Limitations of ther erlang standard library apply (particularly :math.pow/2 raises for VERY large numbers)."},{"ref":"Statistex.html#average/2","title":"Statistex.average/2","type":"function","doc":"Calculate the average. It&#39;s.. well the average. When the given samples are empty there is no average. Argumenterror is raised if the given list is empty. Options If you already have these values, you can provide both :total and :sample_size. Should you provide both the provided samples are wholly ignored. Examples iex&gt; Statistex.average([5]) 5.0 iex&gt; Statistex.average([600, 470, 170, 430, 300]) 394.0 iex&gt; Statistex.average([-1, 1]) 0.0 iex&gt; Statistex.average([2, 3, 4], sample_size: 3) 3.0 iex&gt; Statistex.average([20, 20, 20, 20, 20], total: 100, sample_size: 5) 20.0 iex&gt; Statistex.average(:ignored, total: 100, sample_size: 5) 20.0 iex&gt; Statistex.average([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#frequency_distribution/1","title":"Statistex.frequency_distribution/1","type":"function","doc":"A map showing which sample occurs how often in the samples. Goes from a concrete occurence of the sample to the number of times it was observed in the samples. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.frequency_distribution([1, 2, 4.23, 7, 2, 99]) %{ 2 =&gt; 2, 1 =&gt; 1, 4.23 =&gt; 1, 7 =&gt; 1, 99 =&gt; 1 } iex&gt; Statistex.frequency_distribution([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#maximum/1","title":"Statistex.maximum/1","type":"function","doc":"The biggest sample. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.maximum([1, 100, 24]) 100 iex&gt; Statistex.maximum([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#median/2","title":"Statistex.median/2","type":"function","doc":"Calculates the median of the given samples. The median can be thought of separating the higher half from the lower half of the samples. When all samples are sorted, this is the middle value (or average of the two middle values when the number of times is even). More stable than the average. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.median([1, 3, 4, 6, 7, 8, 9]) 6.0 iex&gt; Statistex.median([1, 2, 3, 4, 5, 6, 8, 9]) 4.5 iex&gt; Statistex.median([0]) 0.0 iex&gt; Statistex.median([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#minimum/1","title":"Statistex.minimum/1","type":"function","doc":"The smallest sample. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.minimum([1, 100, 24]) 1 iex&gt; Statistex.minimum([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#mode/2","title":"Statistex.mode/2","type":"function","doc":"Calculates the mode of the given samples. Mode is the sample(s) that occur the most. Often one value, but can be multiple values if they occur the same amount of times. If no value occurs at least twice, there is no mode and it hence returns nil. Argumenterror is raised if the given list is empty. Options If already calculated, the :frequency_distribution option can be provided to avoid recalulating it. Examples iex&gt; Statistex.mode([5, 3, 4, 5, 1, 3, 1, 3]) 3 iex&gt; Statistex.mode([1, 2, 3, 4, 5]) nil iex&gt; Statistex.mode([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number. iex&gt; mode = Statistex.mode([5, 3, 4, 5, 1, 3, 1]) iex&gt; Enum.sort(mode) [1, 3, 5]"},{"ref":"Statistex.html#percentiles/2","title":"Statistex.percentiles/2","type":"function","doc":"Calculates the value at the percentile_rank-th percentile. Think of this as the value below which percentile_rank percent of the samples lie. For example, if Statistex.percentile(samples, 99) == 123.45, 99% of samples are less than 123.45. Passing a number for percentile_rank calculates a single percentile. Passing a list of numbers calculates multiple percentiles, and returns them as a map like %{90 =&gt; 45.6, 99 =&gt; 78.9}, where the keys are the percentile numbers, and the values are the percentile values. Percentiles must be between 0 and 100 (excluding the boundaries). The method used for interpolation is described here and recommended by NIST. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 12.5) %{12.5 =&gt; 1.0} iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], [50]) %{50 =&gt; 3.0} iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], [75]) %{75 =&gt; 4.75} iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 99) %{99 =&gt; 5.0} iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], [50, 75, 99]) %{50 =&gt; 3.0, 75 =&gt; 4.75, 99 =&gt; 5.0} iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 100) ** (ArgumentError) percentile must be between 0 and 100, got: 100 iex&gt; Statistex.percentiles([5, 3, 4, 5, 1, 3, 1, 3], 0) ** (ArgumentError) percentile must be between 0 and 100, got: 0 iex&gt; Statistex.percentiles([], [50]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#sample_size/1","title":"Statistex.sample_size/1","type":"function","doc":"Number of samples in the given list. Nothing to fancy here, this just calls length(list) and is only provided for completeness sake. Examples iex&gt; Statistex.sample_size([]) 0 iex&gt; Statistex.sample_size([1, 1, 1, 1, 1]) 5"},{"ref":"Statistex.html#standard_deviation/2","title":"Statistex.standard_deviation/2","type":"function","doc":"Calculate the standard deviation. A measurement how much samples vary (the higher the more the samples vary). It&#39;s the square root of the variance. Unlike the variance, its unit is the same as that of the sample (as calculating the variance includes squaring). Options If already calculated, the :variance option can be provided to avoid recalulating those values. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.standard_deviation([4, 9, 11, 12, 17, 5, 8, 12, 12]) 4.0 iex&gt; Statistex.standard_deviation([4, 9, 11, 12, 17, 5, 8, 12, 12], variance: 16.0) 4.0 iex&gt; Statistex.standard_deviation([42]) 0.0 iex&gt; Statistex.standard_deviation([1, 1, 1, 1, 1, 1, 1]) 0.0 iex&gt; Statistex.standard_deviation([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#standard_deviation_ratio/2","title":"Statistex.standard_deviation_ratio/2","type":"function","doc":"Calculate the standard deviation relative to the average. This helps put the absolute standard deviation value into perspective expressing it relative to the average. It&#39;s what percentage of the absolute value of the average the variance takes. Argumenterror is raised if the given list is empty. ## Options If already calculated, the :average and :standard_deviation options can be provided to avoid recalulating those values. If both values are provided, the provided samples will be ignored. ## Examples iex&gt; Statistex.standard_deviation_ratio([4, 9, 11, 12, 17, 5, 8, 12, 12]) 0.4 iex&gt; Statistex.standard_deviation_ratio([-4, -9, -11, -12, -17, -5, -8, -12, -12]) 0.4 iex&gt; Statistex.standard_deviation_ratio([4, 9, 11, 12, 17, 5, 8, 12, 12], average: 10.0, standard_deviation: 4.0) 0.4 iex&gt; Statistex.standard_deviation_ratio(:ignored, average: 10.0, standard_deviation: 4.0) 0.4 iex&gt; Statistex.standard_deviation_ratio([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#statistics/2","title":"Statistex.statistics/2","type":"function","doc":"Calculate all statistics Statistex offers for a given list of numbers. The statistics themselves are described in the individual samples that can be used to calculate individual values. Argumenterror is raised if the given list is empty. Options In a percentiles options arguments for the calculation of percentiles (see percentiles/2) can be given. The 50th percentile is always calculated as it is the median. Examples iex&gt; Statistex.statistics([200, 400, 400, 400, 500, 500, 500, 700, 900]) %Statistex{ average: 500.0, variance: 40_000.0, standard_deviation: 200.0, standard_deviation_ratio: 0.4, median: 500.0, percentiles: %{50 =&gt; 500.0}, frequency_distribution: %{ 200 =&gt; 1, 400 =&gt; 3, 500 =&gt; 3, 700 =&gt; 1, 900 =&gt; 1 }, mode: [500, 400], minimum: 200, maximum: 900, sample_size: 9, total: 4500 } iex&gt; Statistex.statistics([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number. iex&gt; Statistex.statistics([0, 0, 0, 0]) %Statistex{ average: 0.0, variance: 0.0, standard_deviation: 0.0, standard_deviation_ratio: 0.0, median: 0.0, percentiles: %{50 =&gt; 0.0}, frequency_distribution: %{0 =&gt; 4}, mode: 0, minimum: 0, maximum: 0, sample_size: 4, total: 0 }"},{"ref":"Statistex.html#total/1","title":"Statistex.total/1","type":"function","doc":"The total of all samples added together. Argumenterror is raised if the given list is empty. Examples iex&gt; Statistex.total([1, 2, 3, 4, 5]) 15 iex&gt; Statistex.total([10, 10.5, 5]) 25.5 iex&gt; Statistex.total([-10, 5, 3, 2]) 0 iex&gt; Statistex.total([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#variance/2","title":"Statistex.variance/2","type":"function","doc":"Calculate the variance. A measurement how much samples vary (the higher the more the samples vary). This is the variance of a sample and is hence in its calculation divided by sample_size - 1 (Bessel&#39;s correction). Argumenterror is raised if the given list is empty. Options If already calculated, the :average and :sample_size options can be provided to avoid recalulating those values. Examples iex&gt; Statistex.variance([4, 9, 11, 12, 17, 5, 8, 12, 12]) 16.0 iex&gt; Statistex.variance([4, 9, 11, 12, 17, 5, 8, 12, 12], sample_size: 9, average: 10.0) 16.0 iex&gt; Statistex.variance([42]) 0.0 iex&gt; Statistex.variance([1, 1, 1, 1, 1, 1, 1]) 0.0 iex&gt; Statistex.variance([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"Statistex.html#t:configuration/0","title":"Statistex.configuration/0","type":"type","doc":"The optional configuration handed to a lot of functions. Keys used are function dependent and are documented there."},{"ref":"Statistex.html#t:mode/0","title":"Statistex.mode/0","type":"type","doc":"Careful with the mode, might be multiple values, one value or nothing.😱 See mode/1."},{"ref":"Statistex.html#t:percentiles/0","title":"Statistex.percentiles/0","type":"type","doc":"The percentiles map returned by percentiles/2."},{"ref":"Statistex.html#t:sample/0","title":"Statistex.sample/0","type":"type","doc":"A single sample/"},{"ref":"Statistex.html#t:samples/0","title":"Statistex.samples/0","type":"type","doc":"The samples to compute statistics from. Importantly this list is not empty/includes at least one sample otherwise an ArgumentError will be raised."},{"ref":"Statistex.html#t:t/0","title":"Statistex.t/0","type":"type","doc":"All the statistics statistics/1 computes from the samples. For a description of what a given value means please check out the function here by the same name, it will have an explanation."},{"ref":"readme.html","title":"Statistex","type":"extras","doc":"Statistex Statistex helps you do common statistics calculations and to explore a data set. It focusses on two things: providing you a statistics/2 function that just computes all statistics it knows for a data set, reusing previously made calculations to not compute something again (for instance standard deviation needs the average, so it first computes the average and then passes it on): Statistex.statistics(samples) gives you the opportunity to pass known values to functions so that it doesn&#39;t need to compute more than it absolutely needs to: Statistex.standard_deviation(samples, average: computed_average)"},{"ref":"readme.html#installation","title":"Statistex - Installation","type":"extras","doc":"def deps do [ {:statistex, &quot;~&gt; 1.0&quot;} ] end Supported elixir versions are 1.6+ (together with their respective erlang OTP versions aka 19+)."},{"ref":"readme.html#usage","title":"Statistex - Usage","type":"extras","doc":"Check out the documentation but here is a small overview: iex&gt; samples = [1, 3.0, 2.35, 11.0, 1.37, 35, 5.5, 10, 0, 2.35] # calculate all available statistics at once, efficiently reusing already calculated values iex&gt; Statistex.statistics(samples) %Statistex{ average: 7.156999999999999, frequency_distribution: %{ 0 =&gt; 1, 1 =&gt; 1, 10 =&gt; 1, 35 =&gt; 1, 1.37 =&gt; 1, 2.35 =&gt; 2, 3.0 =&gt; 1, 5.5 =&gt; 1, 11.0 =&gt; 1 }, maximum: 35, median: 2.675, minimum: 0, mode: 2.35, percentiles: %{50 =&gt; 2.675}, sample_size: 10, standard_deviation: 10.47189577445799, standard_deviation_ratio: 1.46316833512058, total: 71.57, variance: 109.6606011111111 } # or just calculate the value you need iex&gt; Statistex.average(samples) 7.156999999999999 # Calculate the value you want reusing values you already know # (check the docs for what functions accepts what options) iex&gt; Statistex.average(samples, sample_size: 10) 7.156999999999999 # Most Statistex functions raise given an empty list as most functions don&#39;t make sense then. # It is recommended that you manually handle the empty list case should that occur as your # output is likely also very different from when you have statistics. iex&gt; Statistex.statistics([]) ** (ArgumentError) Passed an empty list ([]) to calculate statistics from, please pass a list containing at least on number."},{"ref":"readme.html#supported-statistics","title":"Statistex - Supported Statistics","type":"extras","doc":"For an up to date overview with explanations please check out the documentation. Statistics currently supported: average frequency_distribution maximum median minimum mode percentiles sample_size standard_deviation standard_deviation_ratio total variance"},{"ref":"readme.html#alternatives","title":"Statistex - Alternatives","type":"extras","doc":"In elixir there are 2 notable other libraries that I&#39;m aware of: statistics and Numerix. Both include more functions than just for statistics: general math and more (drawing of random values for instance). They also have more statistics related functions as of this writing. So if you&#39;e looking for something, that Statistex doesn&#39;t provide (yet) these are some of the first places I&#39;d look. Why would you still want to use Statistex? statistics/2 is really nice when you&#39;re just exploring a data set or just want to have everything at once when calling statistics/2 Statistex reuses previously calculated values (average for standard_deviation for instance, or a sorted list of samples for some calculations) which makes for more efficient calculations. Statistex extends that capability to you so that you can pass pre calculated values as optional arguments. small and focussed on just statistics :) We&#39;re naturally also looking to add more statistical functions as we go along, and pull requests are very welcome :)"},{"ref":"readme.html#performance","title":"Statistex - Performance","type":"extras","doc":"Statistex is written in pure elixir. C-extensions and friends would surely be faster. The goal of statistex is to be as fast possible in pure elixir while providing correct results. Hence, the focus on reusing previously calculated values and providing that ability to users."},{"ref":"readme.html#history","title":"Statistex - History","type":"extras","doc":"Statistex was extracted from benchee and as such it powers benchees statistics calculations. Its great ancestor (if you will) was first conceived in this commit."},{"ref":"readme.html#contributing","title":"Statistex - Contributing","type":"extras","doc":"Contributions to benchee are very welcome! Bug reports, documentation, spelling corrections, new statistics, bugfixes... all of those (and probably more) are much appreciated contributions! Please respect the Code of Conduct. You can also look directly at the open issues. A couple of (hopefully) helpful points: Feel free to ask for help and guidance on an issue/PR (&quot;How can I implement this?&quot;, &quot;How could I test this?&quot;, ...) Feel free to open early/not yet complete pull requests to get some early feedback When in doubt if something is a good idea open an issue first to discuss it In case I don&#39;t respond feel free to bump the issue/PR or ping me in other places"},{"ref":"readme.html#development","title":"Statistex - Development","type":"extras","doc":"mix deps.get to install dependencies mix test to run tests mix dialyzer to run dialyzer for type checking, might take a while on the first invocation (try building plts first with mix dialyzer --plt) mix credo --strict to find code style problems"}]